@@ -26,21 +26,28 @@ class Col : public Mat<eT>
   
   
   inline          Col();
-  inline explicit Col(const u32 n_elem);
-  inline          Col(const u32 in_rows, const u32 in_cols);
+  inline explicit Col(const uword n_elem);
+  inline          Col(const uword in_rows, const uword in_cols);
   
   inline                  Col(const char*        text);
   inline const Col& operator=(const char*        text);
+  
   inline                  Col(const std::string& text);
   inline const Col& operator=(const std::string& text);
   
+  #if defined(ARMA_USE_CXX11)
+  inline                  Col(const std::initializer_list<eT>& list);
+  inline const Col& operator=(const std::initializer_list<eT>& list);
+  #endif
+  
+  
   inline const Col& operator=(const eT val);
     
   template<typename T1> inline                   Col(const Base<eT,T1>& X);
   template<typename T1> inline const Col&  operator=(const Base<eT,T1>& X);
   
-  inline Col(      eT* aux_mem, const u32 aux_length, const bool copy_aux_mem = true, const bool strict = true);
-  inline Col(const eT* aux_mem, const u32 aux_length);
+  inline Col(      eT* aux_mem, const uword aux_length, const bool copy_aux_mem = true, const bool strict = true);
+  inline Col(const eT* aux_mem, const uword aux_length);
   
   template<typename T1, typename T2>
   inline explicit Col(const Base<pod_type,T1>& A, const Base<pod_type,T2>& B);
@@ -53,14 +60,14 @@ class Col : public Mat<eT>
   
   inline mat_injector<Col> operator<<(const eT val);
   
-  arma_inline eT& row(const u32 row_num);
-  arma_inline eT  row(const u32 row_num) const;
+  arma_inline eT& row(const uword row_num);
+  arma_inline eT  row(const uword row_num) const;
   
-  arma_inline       subview_col<eT> rows(const u32 in_row1, const u32 in_row2);
-  arma_inline const subview_col<eT> rows(const u32 in_row1, const u32 in_row2) const;
+  arma_inline       subview_col<eT> rows(const uword in_row1, const uword in_row2);
+  arma_inline const subview_col<eT> rows(const uword in_row1, const uword in_row2) const;
   
-  arma_inline       subview_col<eT> subvec(const u32 in_row1, const u32 in_row2);
-  arma_inline const subview_col<eT> subvec(const u32 in_row1, const u32 in_row2) const;
+  arma_inline       subview_col<eT> subvec(const uword in_row1, const uword in_row2);
+  arma_inline const subview_col<eT> subvec(const uword in_row1, const uword in_row2) const;
   
   arma_inline       subview_col<eT> subvec(const span& row_span);
   arma_inline const subview_col<eT> subvec(const span& row_span) const;
@@ -69,24 +76,24 @@ class Col : public Mat<eT>
   //arma_inline const subview_col<eT> operator()(const span& row_span) const;
   
   
-  inline void shed_row (const u32 row_num);
-  inline void shed_rows(const u32 in_row1, const u32 in_row2);
+  inline void shed_row (const uword row_num);
+  inline void shed_rows(const uword in_row1, const uword in_row2);
   
-                        inline void insert_rows(const u32 row_num, const u32 N, const bool set_to_zero = true);
-  template<typename T1> inline void insert_rows(const u32 row_num, const Base<eT,T1>& X);
+                        inline void insert_rows(const uword row_num, const uword N, const bool set_to_zero = true);
+  template<typename T1> inline void insert_rows(const uword row_num, const Base<eT,T1>& X);
   
   
   typedef       eT*       row_iterator;
   typedef const eT* const_row_iterator;
   
-  inline       row_iterator begin_row(const u32 row_num);
-  inline const_row_iterator begin_row(const u32 row_num) const;
+  inline       row_iterator begin_row(const uword row_num);
+  inline const_row_iterator begin_row(const uword row_num) const;
   
-  inline       row_iterator end_row  (const u32 row_num);
-  inline const_row_iterator end_row  (const u32 row_num) const;
+  inline       row_iterator end_row  (const uword row_num);
+  inline const_row_iterator end_row  (const uword row_num) const;
   
   
-  template<u32 fixed_n_elem>
+  template<uword fixed_n_elem>
   class fixed : public Col<eT>
     {
     private:
@@ -101,9 +108,9 @@ class Col : public Mat<eT>
     
     public:
     
-    static const u32 n_rows = fixed_n_elem;
-    static const u32 n_cols = 1;
-    static const u32 n_elem = fixed_n_elem;
+    static const uword n_rows = fixed_n_elem;
+    static const uword n_cols = 1;
+    static const uword n_elem = fixed_n_elem;
     
     arma_inline fixed();
     arma_inline fixed(const fixed<fixed_n_elem>& X);
@@ -125,26 +132,26 @@ class Col : public Mat<eT>
     inline const Col& operator=(const std::string& text);
     inline const Col& operator=(const subview_cube<eT>& X);
     
-    inline       subview_row<eT> operator()(const u32   row_num,  const span& col_span);
-    inline const subview_row<eT> operator()(const u32   row_num,  const span& col_span) const;
+    inline       subview_row<eT> operator()(const uword   row_num,  const span& col_span);
+    inline const subview_row<eT> operator()(const uword   row_num,  const span& col_span) const;
     
-    inline       subview_col<eT> operator()(const span& row_span, const u32   col_num );
-    inline const subview_col<eT> operator()(const span& row_span, const u32   col_num ) const;
+    inline       subview_col<eT> operator()(const span& row_span, const uword   col_num );
+    inline const subview_col<eT> operator()(const span& row_span, const uword   col_num ) const;
     
     inline       subview<eT>     operator()(const span& row_span, const span& col_span);
     inline const subview<eT>     operator()(const span& row_span, const span& col_span) const;
     
-    arma_inline arma_warn_unused eT& operator[] (const u32 i);
-    arma_inline arma_warn_unused eT  operator[] (const u32 i) const;
-    arma_inline arma_warn_unused eT& at         (const u32 i);
-    arma_inline arma_warn_unused eT  at         (const u32 i) const;
-    arma_inline arma_warn_unused eT& operator() (const u32 i);
-    arma_inline arma_warn_unused eT  operator() (const u32 i) const;
+    arma_inline arma_warn_unused eT& operator[] (const uword i);
+    arma_inline arma_warn_unused eT  operator[] (const uword i) const;
+    arma_inline arma_warn_unused eT& at         (const uword i);
+    arma_inline arma_warn_unused eT  at         (const uword i) const;
+    arma_inline arma_warn_unused eT& operator() (const uword i);
+    arma_inline arma_warn_unused eT  operator() (const uword i) const;
     
-    arma_inline arma_warn_unused eT& at         (const u32 in_row, const u32 in_col);
-    arma_inline arma_warn_unused eT  at         (const u32 in_row, const u32 in_col) const;
-    arma_inline arma_warn_unused eT& operator() (const u32 in_row, const u32 in_col);
-    arma_inline arma_warn_unused eT  operator() (const u32 in_row, const u32 in_col) const;
+    arma_inline arma_warn_unused eT& at         (const uword in_row, const uword in_col);
+    arma_inline arma_warn_unused eT  at         (const uword in_row, const uword in_col) const;
+    arma_inline arma_warn_unused eT& operator() (const uword in_row, const uword in_col);
+    arma_inline arma_warn_unused eT  operator() (const uword in_row, const uword in_col) const;
     
     arma_hot inline const Col<eT>& fill(const eT val);
     arma_hot inline const Col<eT>& zeros();
