@@ -21,13 +21,13 @@ class op_sort
   public:
   
   template<typename eT>
-  inline static void copy_row(eT* X, const Mat<eT>& A, const u32 row);
+  inline static void copy_row(eT* X, const Mat<eT>& A, const uword row);
   
   template<typename eT>
-  inline static void copy_row(Mat<eT>& A, const eT* X, const u32 row);
+  inline static void copy_row(Mat<eT>& A, const eT* X, const uword row);
   
   template<typename eT>
-  inline static void direct_sort(eT* X, const u32 N, const u32 sort_type = 0);
+  inline static void direct_sort(eT* X, const uword N, const uword sort_type = 0);
   
   template<typename T1>
   inline static void apply(Mat<typename T1::elem_type>& out, const Op<T1,op_sort>& in);
