@@ -27,18 +27,18 @@ class subview_field
   
   typedef oT object_type;
   
-  const u32 aux_row1;
-  const u32 aux_col1;
+  const uword aux_row1;
+  const uword aux_col1;
   
-  const u32 n_rows;
-  const u32 n_cols;
-  const u32 n_elem;
+  const uword n_rows;
+  const uword n_cols;
+  const uword n_elem;
   
   
   protected:
   
-  arma_inline subview_field(const field<oT>& in_f, const u32 in_row1, const u32 in_col1, const u32 in_n_rows, const u32 in_n_cols);
-  arma_inline subview_field(      field<oT>& in_f, const u32 in_row1, const u32 in_col1, const u32 in_n_rows, const u32 in_n_cols);
+  arma_inline subview_field(const field<oT>& in_f, const uword in_row1, const uword in_col1, const uword in_n_rows, const uword in_n_cols);
+  arma_inline subview_field(      field<oT>& in_f, const uword in_row1, const uword in_col1, const uword in_n_rows, const uword in_n_cols);
   
   
   public:
@@ -48,17 +48,17 @@ class subview_field
   inline void operator= (const field<oT>& x);
   inline void operator= (const subview_field& x);
   
-  arma_inline       oT& operator[](const u32 i);
-  arma_inline const oT& operator[](const u32 i) const;
+  arma_inline       oT& operator[](const uword i);
+  arma_inline const oT& operator[](const uword i) const;
   
-  arma_inline       oT& operator()(const u32 i);
-  arma_inline const oT& operator()(const u32 i) const;
+  arma_inline       oT& operator()(const uword i);
+  arma_inline const oT& operator()(const uword i) const;
   
-  arma_inline       oT&         at(const u32 row, const u32 col);
-  arma_inline const oT&         at(const u32 row, const u32 col) const;
+  arma_inline       oT&         at(const uword row, const uword col);
+  arma_inline const oT&         at(const uword row, const uword col) const;
   
-  arma_inline       oT& operator()(const u32 row, const u32 col);
-  arma_inline const oT& operator()(const u32 row, const u32 col) const;
+  arma_inline       oT& operator()(const uword row, const uword col);
+  arma_inline const oT& operator()(const uword row, const uword col) const;
   
   inline bool check_overlap(const subview_field& x) const;
   
