@@ -1,5 +1,5 @@
-// Copyright (C) 2008-2010 NICTA (www.nicta.com.au)
-// Copyright (C) 2008-2010 Conrad Sanderson
+// Copyright (C) 2008-2011 NICTA (www.nicta.com.au)
+// Copyright (C) 2008-2011 Conrad Sanderson
 // 
 // This file is part of the Armadillo C++ library.
 // It is provided without any warranty of fitness
@@ -181,7 +181,7 @@ template<typename eT>
 class unwrap_check< Row<eT> >
   {
   public:
-
+  
   inline
   unwrap_check(const Row<eT>& A, const Mat<eT>& B)
     : M_local( (&A == reinterpret_cast<const Row<eT>*>(&B)) ? new Row<eT>(A) : 0 )
@@ -391,10 +391,7 @@ class partial_unwrap
   typedef typename T1::elem_type eT;
   
   inline partial_unwrap(const T1& A)  // TODO: change this to Base ?
-    : do_trans(false)
-    , do_times(false)
-    , val     (1)
-    , M       (A)
+    : M(A)
     {
     arma_extra_debug_sigprint();
     }
@@ -406,9 +403,13 @@ class partial_unwrap
     arma_extra_debug_sigprint();
     }
   
-  const bool    do_trans;
-  const bool    do_times;
-  const eT      val;
+  
+  inline eT get_val() const { return eT(1); }
+  
+  
+  static const bool do_trans = false;
+  static const bool do_times = false;
+  
   const Mat<eT> M;
   };
 
@@ -421,10 +422,7 @@ class partial_unwrap< Mat<eT> >
   
   inline
   partial_unwrap(const Mat<eT>& A)
-    : do_trans(false)
-    , do_times(false)
-    , val     (1)
-    , M       (A)
+    : M(A)
     {
     arma_extra_debug_sigprint();
     }
@@ -437,9 +435,12 @@ class partial_unwrap< Mat<eT> >
     }
   
   
-  const bool     do_trans;
-  const bool     do_times;
-  const eT       val;
+  inline eT get_val() const { return eT(1); }
+  
+  
+  static const bool do_trans = false;
+  static const bool do_times = false;
+  
   const Mat<eT>& M;
   };
 
@@ -452,10 +453,7 @@ class partial_unwrap< Row<eT> >
   
   inline
   partial_unwrap(const Row<eT>& A)
-    : do_trans(false)
-    , do_times(false)
-    , val     (1)
-    , M       (A)
+    : M(A)
     {
     arma_extra_debug_sigprint();
     }
@@ -468,9 +466,12 @@ class partial_unwrap< Row<eT> >
     }
   
   
-  const bool     do_trans;
-  const bool     do_times;
-  const eT       val;
+  inline eT get_val() const { return eT(1); }
+  
+  
+  static const bool do_trans = false;
+  static const bool do_times = false;
+  
   const Mat<eT>& M;
   };
 
@@ -483,10 +484,7 @@ class partial_unwrap< Col<eT> >
   
   inline
   partial_unwrap(const Col<eT>& A)
-    : do_trans(false)
-    , do_times(false)
-    , val     (1)
-    , M       (A)
+    : M(A)
     {
     arma_extra_debug_sigprint();
     }
@@ -499,9 +497,12 @@ class partial_unwrap< Col<eT> >
     }
   
   
-  const bool     do_trans;
-  const bool     do_times;
-  const eT       val;
+  inline eT get_val() const { return eT(1); }
+  
+  
+  static const bool do_trans = false;
+  static const bool do_times = false;
+  
   const Mat<eT>& M;
   };
 
@@ -516,10 +517,7 @@ class partial_unwrap< Op<T1, op_htrans> >
   
   inline
   partial_unwrap(const Op<T1,op_htrans>& A)
-    : do_trans(true)
-    , do_times(false)
-    , val     (1)
-    , M       (A.m)
+    : M(A.m)
     {
     arma_extra_debug_sigprint();
     }
@@ -530,9 +528,13 @@ class partial_unwrap< Op<T1, op_htrans> >
     arma_extra_debug_sigprint();
     }
   
-  const bool    do_trans;
-  const bool    do_times;
-  const eT      val;
+  
+  inline eT get_val() const { return eT(1); }
+  
+  
+  static const bool do_trans = true;
+  static const bool do_times = false;
+  
   const Mat<eT> M;
   };
 
@@ -545,14 +547,12 @@ class partial_unwrap< Op< Mat<eT>, op_htrans> >
   
   inline
   partial_unwrap(const Op< Mat<eT>, op_htrans>& A)
-    : do_trans(true)
-    , do_times(false)
-    , val     (1)
-    , M       (A.m)
+    : M(A.m)
     {
     arma_extra_debug_sigprint();
     }
   
+  
   inline
   ~partial_unwrap()
     {
@@ -560,9 +560,12 @@ class partial_unwrap< Op< Mat<eT>, op_htrans> >
     }
   
   
-  const bool     do_trans;
-  const bool     do_times;
-  const eT       val;
+  inline eT get_val() const { return eT(1); }
+  
+  
+  static const bool do_trans = true;
+  static const bool do_times = false;
+  
   const Mat<eT>& M;
   };
 
@@ -575,10 +578,7 @@ class partial_unwrap< Op< Row<eT>, op_htrans> >
   
   inline
   partial_unwrap(const Op< Row<eT>, op_htrans>& A)
-    : do_trans(true)
-    , do_times(false)
-    , val     (1)
-    , M       (A.m)
+    : M(A.m)
     {
     arma_extra_debug_sigprint();
     }
@@ -590,9 +590,12 @@ class partial_unwrap< Op< Row<eT>, op_htrans> >
     }
   
   
-  const bool     do_trans;
-  const bool     do_times;
-  const eT       val;
+  inline eT get_val() const { return eT(1); }
+  
+  
+  static const bool do_trans = true;
+  static const bool do_times = false;
+  
   const Mat<eT>& M;
   };
 
@@ -605,10 +608,7 @@ class partial_unwrap< Op< Col<eT>, op_htrans> >
   
   inline
   partial_unwrap(const Op< Col<eT>, op_htrans>& A)
-    : do_trans(true)
-    , do_times(false)
-    , val     (1)
-    , M       (A.m)
+    : M(A.m)
     {
     arma_extra_debug_sigprint();
     }
@@ -620,9 +620,12 @@ class partial_unwrap< Op< Col<eT>, op_htrans> >
     }
   
   
-  const bool     do_trans;
-  const bool     do_times;
-  const eT       val;
+  inline eT get_val() const { return eT(1); }
+  
+  
+  static const bool do_trans = true;
+  static const bool do_times = false;
+  
   const Mat<eT>& M;
   };
 
@@ -637,10 +640,8 @@ class partial_unwrap< Op<T1, op_htrans2> >
   
   inline
   partial_unwrap(const Op<T1,op_htrans2>& A)
-    : do_trans(true)
-    , do_times(true)
-    , val     (A.aux)
-    , M       (A.m)
+    : val(A.aux)
+    , M  (A.m)
     {
     arma_extra_debug_sigprint();
     }
@@ -651,8 +652,13 @@ class partial_unwrap< Op<T1, op_htrans2> >
     arma_extra_debug_sigprint();
     }
   
-  const bool    do_trans;
-  const bool    do_times;
+  
+  inline eT get_val() const { return val; }
+  
+  
+  static const bool do_trans = true;
+  static const bool do_times = true;
+  
   const eT      val;
   const Mat<eT> M;
   };
@@ -666,10 +672,8 @@ class partial_unwrap< Op< Mat<eT>, op_htrans2> >
   
   inline
   partial_unwrap(const Op< Mat<eT>, op_htrans2>& A)
-    : do_trans(true)
-    , do_times(true)
-    , val     (A.aux)
-    , M       (A.m)
+    : val(A.aux)
+    , M  (A.m)
     {
     arma_extra_debug_sigprint();
     }
@@ -681,8 +685,12 @@ class partial_unwrap< Op< Mat<eT>, op_htrans2> >
     }
   
   
-  const bool     do_trans;
-  const bool     do_times;
+  inline eT get_val() const { return val; }
+  
+  
+  static const bool do_trans = true;
+  static const bool do_times = true;
+  
   const eT       val;
   const Mat<eT>& M;
   };
@@ -696,10 +704,8 @@ class partial_unwrap< Op< Row<eT>, op_htrans2> >
   
   inline
   partial_unwrap(const Op< Row<eT>, op_htrans2>& A)
-    : do_trans(true)
-    , do_times(true)
-    , val     (A.aux)
-    , M       (A.m)
+    : val(A.aux)
+    , M  (A.m)
     {
     arma_extra_debug_sigprint();
     }
@@ -711,8 +717,12 @@ class partial_unwrap< Op< Row<eT>, op_htrans2> >
     }
   
   
-  const bool     do_trans;
-  const bool     do_times;
+  inline eT get_val() const { return val; }
+  
+  
+  static const bool do_trans = true;
+  static const bool do_times = true;
+  
   const eT       val;
   const Mat<eT>& M;
   };
@@ -726,10 +736,8 @@ class partial_unwrap< Op< Col<eT>, op_htrans2> >
   
   inline
   partial_unwrap(const Op< Col<eT>, op_htrans2>& A)
-    : do_trans(true)
-    , do_times(true)
-    , val     (A.aux)
-    , M       (A.m)
+    : val(A.aux)
+    , M  (A.m)
     {
     arma_extra_debug_sigprint();
     }
@@ -741,8 +749,12 @@ class partial_unwrap< Op< Col<eT>, op_htrans2> >
     }
   
   
-  const bool     do_trans;
-  const bool     do_times;
+  inline eT get_val() const { return val; }
+  
+  
+  static const bool do_trans = true;
+  static const bool do_times = true;
+  
   const eT       val;
   const Mat<eT>& M;
   };
@@ -758,10 +770,8 @@ class partial_unwrap< eOp<T1, eop_scalar_times> >
   
   inline
   partial_unwrap(const eOp<T1,eop_scalar_times>& A)
-    : do_trans(false)
-    , do_times(true)
-    , val     (A.aux)
-    , M       (A.P.Q)
+    : val(A.aux)
+    , M  (A.P.Q)
     {
     arma_extra_debug_sigprint();
     }
@@ -772,8 +782,13 @@ class partial_unwrap< eOp<T1, eop_scalar_times> >
     arma_extra_debug_sigprint();
     }
   
-  const bool    do_trans;
-  const bool    do_times;
+  
+  inline eT get_val() const { return val; }
+  
+  
+  static const bool do_trans = false;
+  static const bool do_times = true;
+  
   const eT      val;
   const Mat<eT> M;
   };
@@ -787,10 +802,8 @@ class partial_unwrap< eOp<Mat<eT>, eop_scalar_times> >
   
   inline
   partial_unwrap(const eOp<Mat<eT>,eop_scalar_times>& A)
-    : do_trans(false)
-    , do_times(true)
-    , val     (A.aux)
-    , M       (A.P.Q)
+    : val(A.aux)
+    , M  (A.P.Q)
     {
     arma_extra_debug_sigprint();
     }
@@ -801,8 +814,13 @@ class partial_unwrap< eOp<Mat<eT>, eop_scalar_times> >
     arma_extra_debug_sigprint();
     }
   
-  const bool     do_trans;
-  const bool     do_times;
+  
+  inline eT get_val() const { return val; }
+  
+  
+  static const bool do_trans = false;
+  static const bool do_times = true;
+  
   const eT       val;
   const Mat<eT>& M;
   };
@@ -816,10 +834,8 @@ class partial_unwrap< eOp<Row<eT>, eop_scalar_times> >
   
   inline
   partial_unwrap(const eOp<Row<eT>,eop_scalar_times>& A)
-    : do_trans(false)
-    , do_times(true)
-    , val     (A.aux)
-    , M       (A.P.Q)
+    : val(A.aux)
+    , M  (A.P.Q)
     {
     arma_extra_debug_sigprint();
     }
@@ -830,8 +846,13 @@ class partial_unwrap< eOp<Row<eT>, eop_scalar_times> >
     arma_extra_debug_sigprint();
     }
   
-  const bool     do_trans;
-  const bool     do_times;
+  
+  inline eT get_val() const { return val; }
+  
+  
+  static const bool do_trans = false;
+  static const bool do_times = true;
+  
   const eT       val;
   const Mat<eT>& M;
   };
@@ -845,10 +866,8 @@ class partial_unwrap< eOp<Col<eT>, eop_scalar_times> >
   
   inline
   partial_unwrap(const eOp<Col<eT>,eop_scalar_times>& A)
-    : do_trans(false)
-    , do_times(true)
-    , val     (A.aux)
-    , M       (A.P.Q)
+    : val(A.aux)
+    , M  (A.P.Q)
     {
     arma_extra_debug_sigprint();
     }
@@ -859,8 +878,13 @@ class partial_unwrap< eOp<Col<eT>, eop_scalar_times> >
     arma_extra_debug_sigprint();
     }
   
-  const bool     do_trans;
-  const bool     do_times;
+  
+  inline eT get_val() const { return val; }
+  
+  
+  static const bool do_trans = false;
+  static const bool do_times = true;
+  
   const eT       val;
   const Mat<eT>& M;
   };
@@ -879,10 +903,7 @@ class partial_unwrap_check
   typedef typename T1::elem_type eT;
   
   inline partial_unwrap_check(const T1& A, const Mat<eT>& B)
-    : do_trans(false)
-    , do_times(false)
-    , val     (1)
-    , M       (A)
+    : M(A)
     {
     arma_extra_debug_sigprint();
     arma_ignore(B);
@@ -895,9 +916,13 @@ class partial_unwrap_check
     arma_extra_debug_sigprint();
     }
   
-  const bool    do_trans;
-  const bool    do_times;
-  const eT      val;
+  
+  inline eT get_val() const { return eT(1); }
+  
+  
+  static const bool do_trans = false;
+  static const bool do_times = false;
+  
   const Mat<eT> M;
   };
 
@@ -910,10 +935,7 @@ class partial_unwrap_check< Mat<eT> >
   
   inline
   partial_unwrap_check(const Mat<eT>& A, const Mat<eT>& B)
-    : do_trans(false)
-    , do_times(false)
-    , val     (1)
-    , M_local ( (&A == &B) ? new Mat<eT>(A) : 0 )
+    : M_local ( (&A == &B) ? new Mat<eT>(A) : 0 )
     , M       ( (&A == &B) ? (*M_local)     : A )
     {
     arma_extra_debug_sigprint();
@@ -932,10 +954,13 @@ class partial_unwrap_check< Mat<eT> >
     }
   
   
+  inline eT get_val() const { return eT(1); }
+  
+  
+  static const bool do_trans = false;
+  static const bool do_times = false;
+  
   // the order below is important
-  const bool     do_trans;
-  const bool     do_times;
-  const eT       val;
   const Mat<eT>* M_local;
   const Mat<eT>& M;
   };
@@ -949,10 +974,7 @@ class partial_unwrap_check< Row<eT> >
   
   inline
   partial_unwrap_check(const Row<eT>& A, const Mat<eT>& B)
-    : do_trans(false)
-    , do_times(false)
-    , val     (1)
-    , M_local ( (&A == &B) ? new Mat<eT>(A) : 0 )
+    : M_local ( (&A == &B) ? new Mat<eT>(A) : 0 )
     , M       ( (&A == &B) ? (*M_local)     : A )
     {
     arma_extra_debug_sigprint();
@@ -971,10 +993,13 @@ class partial_unwrap_check< Row<eT> >
     }
   
   
+  inline eT get_val() const { return eT(1); }
+  
+  
+  static const bool do_trans = false;
+  static const bool do_times = false;
+  
   // the order below is important
-  const bool     do_trans;
-  const bool     do_times;
-  const eT       val;
   const Mat<eT>* M_local;
   const Mat<eT>& M;
   };
@@ -988,10 +1013,7 @@ class partial_unwrap_check< Col<eT> >
   
   inline
   partial_unwrap_check(const Col<eT>& A, const Mat<eT>& B)
-    : do_trans(false)
-    , do_times(false)
-    , val     (1)
-    , M_local ( (&A == &B) ? new Mat<eT>(A) : 0 )
+    : M_local ( (&A == &B) ? new Mat<eT>(A) : 0 )
     , M       ( (&A == &B) ? (*M_local)     : A )
     {
     arma_extra_debug_sigprint();
@@ -1010,10 +1032,13 @@ class partial_unwrap_check< Col<eT> >
     }
   
   
+  inline eT get_val() const { return eT(1); }
+  
+  
+  static const bool do_trans = false;
+  static const bool do_times = false;
+  
   // the order below is important
-  const bool     do_trans;
-  const bool     do_times;
-  const eT       val;
   const Mat<eT>* M_local;
   const Mat<eT>& M;
   };
@@ -1029,10 +1054,7 @@ class partial_unwrap_check< Op<T1, op_htrans> >
   
   inline
   partial_unwrap_check(const Op<T1,op_htrans>& A, const Mat<eT>& B)
-    : do_trans(true)
-    , do_times(false)
-    , val     (1)
-    , M       (A.m)
+    : M(A.m)
     {
     arma_extra_debug_sigprint();
     arma_ignore(B);
@@ -1044,9 +1066,13 @@ class partial_unwrap_check< Op<T1, op_htrans> >
     arma_extra_debug_sigprint();
     }
   
-  const bool    do_trans;
-  const bool    do_times;
-  const eT      val;
+  
+  inline eT get_val() const { return eT(1); }
+  
+  
+  static const bool do_trans = true;
+  static const bool do_times = false;
+  
   const Mat<eT> M;
   };
 
@@ -1059,10 +1085,7 @@ class partial_unwrap_check< Op< Mat<eT>, op_htrans> >
   
   inline
   partial_unwrap_check(const Op< Mat<eT>, op_htrans>& A, const Mat<eT>& B)
-    : do_trans(true)
-    , do_times(false)
-    , val     (1)
-    , M_local ( (&A.m == &B) ? new Mat<eT>(A.m) : 0   )
+    : M_local ( (&A.m == &B) ? new Mat<eT>(A.m) : 0   )
     , M       ( (&A.m == &B) ? (*M_local)       : A.m )
     {
     arma_extra_debug_sigprint();
@@ -1080,10 +1103,13 @@ class partial_unwrap_check< Op< Mat<eT>, op_htrans> >
     }
   
   
+  inline eT get_val() const { return eT(1); }
+  
+  
+  static const bool do_trans = true;
+  static const bool do_times = false;
+  
   // the order below is important
-  const bool     do_trans;
-  const bool     do_times;
-  const eT       val;
   const Mat<eT>* M_local;
   const Mat<eT>& M;
   };
@@ -1097,10 +1123,7 @@ class partial_unwrap_check< Op< Row<eT>, op_htrans> >
   
   inline
   partial_unwrap_check(const Op< Row<eT>, op_htrans>& A, const Mat<eT>& B)
-    : do_trans(true)
-    , do_times(false)
-    , val     (1)
-    , M_local ( (&A.m == &B) ? new Mat<eT>(A.m) : 0   )
+    : M_local ( (&A.m == &B) ? new Mat<eT>(A.m) : 0   )
     , M       ( (&A.m == &B) ? (*M_local)       : A.m )
     {
     arma_extra_debug_sigprint();
@@ -1118,10 +1141,13 @@ class partial_unwrap_check< Op< Row<eT>, op_htrans> >
     }
   
   
+  inline eT get_val() const { return eT(1); }
+  
+  
+  static const bool do_trans = true;
+  static const bool do_times = false;
+  
   // the order below is important
-  const bool     do_trans;
-  const bool     do_times;
-  const eT       val;
   const Mat<eT>* M_local;
   const Mat<eT>& M;
   };
@@ -1135,10 +1161,7 @@ class partial_unwrap_check< Op< Col<eT>, op_htrans> >
   
   inline
   partial_unwrap_check(const Op< Col<eT>, op_htrans>& A, const Mat<eT>& B)
-    : do_trans(true)
-    , do_times(false)
-    , val     (1)
-    , M_local ( (&A.m == &B) ? new Mat<eT>(A.m) : 0   )
+    : M_local ( (&A.m == &B) ? new Mat<eT>(A.m) : 0   )
     , M       ( (&A.m == &B) ? (*M_local)       : A.m )
     {
     arma_extra_debug_sigprint();
@@ -1156,10 +1179,13 @@ class partial_unwrap_check< Op< Col<eT>, op_htrans> >
     }
   
   
+  inline eT get_val() const { return eT(1); }
+  
+  
+  static const bool do_trans = true;
+  static const bool do_times = false;
+  
   // the order below is important
-  const bool     do_trans;
-  const bool     do_times;
-  const eT       val;
   const Mat<eT>* M_local;
   const Mat<eT>& M;
   };
@@ -1175,10 +1201,8 @@ class partial_unwrap_check< Op<T1, op_htrans2> >
   
   inline
   partial_unwrap_check(const Op<T1,op_htrans2>& A, const Mat<eT>& B)
-    : do_trans(true)
-    , do_times(true)
-    , val     (A.aux)
-    , M       (A.m)
+    : val(A.aux)
+    , M  (A.m)
     {
     arma_extra_debug_sigprint();
     }
@@ -1189,8 +1213,13 @@ class partial_unwrap_check< Op<T1, op_htrans2> >
     arma_extra_debug_sigprint();
     }
   
-  const bool    do_trans;
-  const bool    do_times;
+  
+  inline eT get_val() const { return val; }
+  
+  
+  static const bool do_trans = true;
+  static const bool do_times = true;
+  
   const eT      val;
   const Mat<eT> M;
   };
@@ -1204,9 +1233,7 @@ class partial_unwrap_check< Op< Mat<eT>, op_htrans2> >
   
   inline
   partial_unwrap_check(const Op< Mat<eT>, op_htrans2>& A, const Mat<eT>& B)
-    : do_trans(true)
-    , do_times(true)
-    , val     (A.aux)
+    : val     (A.aux)
     , M_local ( (&A.m == &B) ? new Mat<eT>(A.m) : 0   )
     , M       ( (&A.m == &B) ? (*M_local)       : A.m )
     {
@@ -1225,9 +1252,13 @@ class partial_unwrap_check< Op< Mat<eT>, op_htrans2> >
     }
   
   
+  inline eT get_val() const { return val; }
+  
+  
+  static const bool do_trans = true;
+  static const bool do_times = true;
+  
   // the order below is important
-  const bool     do_trans;
-  const bool     do_times;
   const eT       val;
   const Mat<eT>* M_local;
   const Mat<eT>& M;
@@ -1242,9 +1273,7 @@ class partial_unwrap_check< Op< Row<eT>, op_htrans2> >
   
   inline
   partial_unwrap_check(const Op< Row<eT>, op_htrans2>& A, const Mat<eT>& B)
-    : do_trans(true)
-    , do_times(true)
-    , val     (A.aux)
+    : val     (A.aux)
     , M_local ( (&A.m == &B) ? new Mat<eT>(A.m) : 0   )
     , M       ( (&A.m == &B) ? (*M_local)       : A.m )
     {
@@ -1263,9 +1292,13 @@ class partial_unwrap_check< Op< Row<eT>, op_htrans2> >
     }
   
   
+  inline eT get_val() const { return val; }
+  
+  
+  static const bool do_trans = true;
+  static const bool do_times = true;
+  
   // the order below is important
-  const bool     do_trans;
-  const bool     do_times;
   const eT       val;
   const Mat<eT>* M_local;
   const Mat<eT>& M;
@@ -1280,9 +1313,7 @@ class partial_unwrap_check< Op< Col<eT>, op_htrans2> >
   
   inline
   partial_unwrap_check(const Op< Mat<eT>, op_htrans2>& A, const Mat<eT>& B)
-    : do_trans(true)
-    , do_times(true)
-    , val     (A.aux)
+    : val     (A.aux)
     , M_local ( (&A.m == &B) ? new Mat<eT>(A.m) : 0   )
     , M       ( (&A.m == &B) ? (*M_local)       : A.m )
     {
@@ -1301,9 +1332,13 @@ class partial_unwrap_check< Op< Col<eT>, op_htrans2> >
     }
   
   
+  inline eT get_val() const { return val; }
+  
+  
+  static const bool do_trans = true;
+  static const bool do_times = true;
+  
   // the order below is important
-  const bool     do_trans;
-  const bool     do_times;
   const eT       val;
   const Mat<eT>* M_local;
   const Mat<eT>& M;
@@ -1320,10 +1355,8 @@ class partial_unwrap_check< eOp<T1, eop_scalar_times> >
   
   inline
   partial_unwrap_check(const eOp<T1,eop_scalar_times>& A, const Mat<eT>& B)
-    : do_trans(false)
-    , do_times(true)
-    , val     (A.aux)
-    , M       (A.P.Q)
+    : val(A.aux)
+    , M  (A.P.Q)
     {
     arma_extra_debug_sigprint();
     arma_ignore(B);
@@ -1335,8 +1368,13 @@ class partial_unwrap_check< eOp<T1, eop_scalar_times> >
     arma_extra_debug_sigprint();
     }
   
-  const bool    do_trans;
-  const bool    do_times;
+  
+  inline eT get_val() const { return val; }
+  
+  
+  static const bool do_trans = false;
+  static const bool do_times = true;
+  
   const eT      val;
   const Mat<eT> M;
   };
@@ -1350,10 +1388,8 @@ class partial_unwrap_check< eOp<Mat<eT>, eop_scalar_times> >
   
   inline
   partial_unwrap_check(const eOp<Mat<eT>,eop_scalar_times>& A, const Mat<eT>& B)
-    : do_trans(false)
-    , do_times(true)
-    , val     (A.aux)
-    , M       (A.P.Q)
+    : val(A.aux)
+    , M  (A.P.Q)
     {
     arma_extra_debug_sigprint();
     arma_ignore(B);
@@ -1365,8 +1401,13 @@ class partial_unwrap_check< eOp<Mat<eT>, eop_scalar_times> >
     arma_extra_debug_sigprint();
     }
   
-  const bool     do_trans;
-  const bool     do_times;
+  
+  inline eT get_val() const { return val; }
+  
+  
+  static const bool do_trans = false;
+  static const bool do_times = true;
+  
   const eT       val;
   const Mat<eT>& M;
   };
@@ -1380,10 +1421,8 @@ class partial_unwrap_check< eOp<Row<eT>, eop_scalar_times> >
   
   inline
   partial_unwrap_check(const eOp<Row<eT>,eop_scalar_times>& A, const Mat<eT>& B)
-    : do_trans(false)
-    , do_times(true)
-    , val     (A.aux)
-    , M       (A.P.Q)
+    : val(A.aux)
+    , M  (A.P.Q)
     {
     arma_extra_debug_sigprint();
     arma_ignore(B);
@@ -1395,8 +1434,13 @@ class partial_unwrap_check< eOp<Row<eT>, eop_scalar_times> >
     arma_extra_debug_sigprint();
     }
   
-  const bool     do_trans;
-  const bool     do_times;
+  
+  inline eT get_val() const { return val; }
+  
+  
+  static const bool do_trans = false;
+  static const bool do_times = true;
+  
   const eT       val;
   const Mat<eT>& M;
   };
@@ -1410,10 +1454,8 @@ class partial_unwrap_check< eOp<Col<eT>, eop_scalar_times> >
   
   inline
   partial_unwrap_check(const eOp<Col<eT>,eop_scalar_times>& A, const Mat<eT>& B)
-    : do_trans(false)
-    , do_times(true)
-    , val     (A.aux)
-    , M       (A.P.Q)
+    : val(A.aux)
+    , M  (A.P.Q)
     {
     arma_extra_debug_sigprint();
     arma_ignore(B);
@@ -1425,8 +1467,13 @@ class partial_unwrap_check< eOp<Col<eT>, eop_scalar_times> >
     arma_extra_debug_sigprint();
     }
   
-  const bool     do_trans;
-  const bool     do_times;
+  
+  inline eT get_val() const { return val; }
+  
+  
+  static const bool do_trans = false;
+  static const bool do_times = true;
+  
   const eT       val;
   const Mat<eT>& M;
   };
